import os
import subprocess
import sys
import shutil

def remove_existing_virtual_environment(env_name=".venv"):
    """Remove existing virtual environment if it exists."""
    if os.path.exists(env_name):
        print(f"Virtual environment '{env_name}' already exists.")
        user_input = input("Do you want to remove it and create a new one? (y/n): ").strip().lower()
        if user_input == "y":
            print(f"Removing existing virtual environment: {env_name}")
            shutil.rmtree(env_name)
        else:
            print("Aborting operation.")
            sys.exit(1)

def create_virtual_environment(env_name=".venv"):
    """Create a virtual environment and install required packages."""
    print(f"Creating virtual environment: {env_name}")
    subprocess.run([sys.executable, "-m", "venv", env_name], check=True)

    python_executable = os.path.join(env_name, "bin", "python")
    if not os.path.exists(python_executable):
        print(f"Error: Python executable not found in the virtual environment at {python_executable}")
        sys.exit(1)

    print("Upgrading pip...")
    subprocess.run([python_executable, "-m", "pip", "install", "--upgrade", "pip"], check=True)

    requirements_file = "requirements.txt"
    if os.path.exists(requirements_file):
        print("Installing dependencies from requirements.txt...")
        subprocess.run([python_executable, "-m", "pip", "install", "-r", requirements_file], check=True)
    else:
        print("Error: requirements.txt file not found.")
        sys.exit(1)

    return python_executable

def install_python_vxi11(env_name=".venv"):
    """Clone and install the python-vxi11 package."""
    print("Cloning and installing python-vxi11 from GitHub...")
    repo_url = "https://github.com/python-ivi/python-vxi11.git"
    clone_dir = os.path.join(env_name, "temp_vxi11")

    # Remove the folder if it already exists
    if os.path.exists(clone_dir):
        print(f"Removing existing cloned repository at {clone_dir}")
        shutil.rmtree(clone_dir)

    subprocess.run(["git", "clone", repo_url, clone_dir], check=True)

    setup_py_path = os.path.join(clone_dir, "setup.py")
    if not os.path.exists(setup_py_path):
        print(f"Error: setup.py not found in {clone_dir}")
        sys.exit(1)

    python_executable = os.path.join(env_name, "bin", "python")
    if not os.path.exists(python_executable):
        print(f"Error: Python executable not found in virtual environment at {python_executable}")
        sys.exit(1)

    print("Installing python-vxi11...")
    subprocess.run([python_executable, "-m", "pip", "install", clone_dir], check=True)

    print("Cleaning up temporary files...")
    shutil.rmtree(clone_dir)

def install_php():
    """Install PHP using apt-get."""
    print("Installing PHP using apt-get...")
    try:
        subprocess.run(["sudo", "apt-get", "update"], check=True)
        subprocess.run(["sudo", "apt-get", "install", "-y", "php"], check=True)
        print("PHP installation completed successfully.")
    except subprocess.CalledProcessError:
        print("An error occurred while installing PHP.")
        sys.exit(1)

if __name__ == "__main__":
    venv_name = ".venv"
    remove_existing_virtual_environment(venv_name)
    python_exec = create_virtual_environment(venv_name)
    install_python_vxi11(venv_name)
    # install_php()
